@@ -69,7 +69,7 @@ class Client:
         # Used to generate default dataset names for uploads
         self.dataset_name_format = "dataset_{}"
         # TODO: This should be changed for prod.
-        self.kodra_url = base_url
+        self.kodra_share_endpoint = base_url + "/api/share/"
 
     def share(
         self, data: pandas.DataFrame, token: str, name: Optional[str] = None
@@ -122,7 +122,7 @@ class Client:
                 ),
             )
             resp = requests.post(
-                self.kodra_url.format("api/share/"),
+                self.kodra_share_endpoint,
                 data=encoder_monitor,
                 headers={
                     "Upload-Token": token,
