@@ -1,6 +1,6 @@
 import unittest
 
-from kodra import Kodra
+from kodra import Kodra, share
 import pandas
 
 
@@ -20,7 +20,7 @@ class KodraTest(unittest.TestCase):
         The method should throw an exception.
         """
         df = pandas.DataFrame()
-        self.assertRaises(ValueError, Kodra().share, data=df, token="")
+        self.assertRaises(ValueError, share, data=df, token="")
 
     def test_share_empty_token(self):
         # pylint: disable=no-member
